@@ -61,10 +61,11 @@ class ClientArgsCreator(object):
 
         event_emitter = copy.copy(self._event_emitter)
         signer = RequestSigner(
-            service_name, signing_region,
+            service_model.service_id, signing_region,
             endpoint_config['signing_name'],
             endpoint_config['signature_version'],
-            credentials, event_emitter)
+            credentials, event_emitter
+        )
 
         config_kwargs['s3'] = s3_config
         new_config = Config(**config_kwargs)
@@ -131,6 +132,7 @@ class ClientArgsCreator(object):
                 read_timeout=client_config.read_timeout,
                 max_pool_connections=client_config.max_pool_connections,
                 proxies=client_config.proxies,
+                retries=client_config.retries
             )
         s3_config = self.compute_s3_config(scoped_config,
                                            client_config)
