@@ -441,9 +441,10 @@ class AWSPreparedRequest(object):
         # just immediately return.  It's not an error, it will produce
         # the same result as if we had actually reset the stream (we'll send
         # the entire body contents again if we need to).
-        # Same case if the body is a string/bytes type.
-        if self.body is None or isinstance(self.body, six.text_type) or \
-           isinstance(self.body, six.binary_type):
+        # Same case if the body is a string/bytes/bytearray type.
+
+        non_seekable_types = (six.binary_type, six.text_type, bytearray)
+        if self.body is None or isinstance(self.body, non_seekable_types):
             return
         try:
             logger.debug("Rewinding stream: %s", self.body)
@@ -463,6 +464,15 @@ class AWSPreparedRequest(object):
         headers = headers or {}
         self.headers = HeadersDict(headers.items())
 
+    def _to_utf8(self, item):
+        key, value = item
+        if isinstance(key, six.text_type):
+            key = key.encode('utf-8')
+        if isinstance(value, six.text_type):
+            value = value.encode('utf-8')
+
+        return key, value
+
     def prepare_body(self, data):
         """Prepares the given HTTP body data."""
         self.body = data
@@ -477,7 +487,7 @@ class AWSPreparedRequest(object):
             self.headers['Content-Length'] = '0'
 
         if isinstance(self.body, dict):
-            params = list(self.body.items())
+            params = [self._to_utf8(item) for item in self.body.items()]
             self.body = urlencode(params, doseq=True)
 
         try:
